@@ -3,7 +3,12 @@
 
 #include "../src/models/incidenceoccurrencemodel.h"
 
+#include <akonadi-calendar_version.h>
+#if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
+#include <Akonadi/IncidenceChanger>
+#else
 #include <Akonadi/Calendar/IncidenceChanger>
+#endif
 #include <KCalendarCore/Incidence>
 #include <KCheckableProxyModel>
 #include <KFormat>
@@ -33,7 +38,7 @@ public:
         }
     }
 
-signals:
+Q_SIGNALS:
     void calendarLoaded();
 
 private:
@@ -43,7 +48,7 @@ private:
     QTimer loadedCheckTimer;
     QDateTime now = QDate(2022, 01, 10).startOfDay();
 
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         AkonadiTest::checkTestIsIsolated();
