@@ -6,7 +6,7 @@
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/AgentInstance>
 #include <QObject>
-#include <akonadi_version.h>
+#include <QTimer>
 
 class AgentConfiguration : public QObject
 {
@@ -14,6 +14,14 @@ class AgentConfiguration : public QObject
     Q_PROPERTY(Akonadi::AgentFilterProxyModel *availableAgents READ availableAgents CONSTANT)
     Q_PROPERTY(Akonadi::AgentFilterProxyModel *runningAgents READ runningAgents CONSTANT)
 public:
+    enum AgentStatuses {
+        Idle = Akonadi::AgentInstance::Idle,
+        Running = Akonadi::AgentInstance::Running,
+        Broken = Akonadi::AgentInstance::Broken,
+        NotConfigured = Akonadi::AgentInstance::NotConfigured,
+    };
+    Q_ENUM(AgentStatuses);
+
     AgentConfiguration(QObject *parent = nullptr);
     ~AgentConfiguration() override;
 
@@ -28,11 +36,17 @@ public:
     Q_INVOKABLE void restart(int index);
     Q_INVOKABLE void restartIdentifier(QString resourceIdentifier);
 
+public Q_SLOTS:
+    void processInstanceProgressChanged(const Akonadi::AgentInstance &instance);
+
+Q_SIGNALS:
+    void agentProgressChanged(const QVariantMap agentData);
+
 private:
     void setupEdit(Akonadi::AgentInstance instance);
     void setupRemove(Akonadi::AgentInstance instance);
     void setupRestart(Akonadi::AgentInstance instance);
 
-    Akonadi::AgentFilterProxyModel *m_runningAgents;
-    Akonadi::AgentFilterProxyModel *m_availableAgents;
+    Akonadi::AgentFilterProxyModel *m_runningAgents = nullptr;
+    Akonadi::AgentFilterProxyModel *m_availableAgents = nullptr;
 };
